/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




/* GPL_HEADER */
package org.greenstone.gatherer.cdm;
/**************************************************************************************
 * Title:        Gatherer
 * Description:  The Gatherer: a tool for gathering and enriching a digital collection.
 * Company:      The University of Waikato
 * Written:      03/05/02
 * Revised:      03/10/02 - Commented
 **************************************************************************************/
import java.util.Collections;
import java.util.StringTokenizer;
import java.util.Vector;
import org.greenstone.gatherer.cdm.Subcollection;
import org.greenstone.gatherer.cdm.SubIndex;
/** The DefaultSubIndex contains a single subcollection which is used as the default index.
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.3
 */
public class DefaultSubIndex
	 extends SubIndex {
	 /** Copy constructor.
	  * @param subindex The <strong>SubIndex</strong> we are copying.
	  */
	 public DefaultSubIndex(SubIndex subindex) {
		  for(int i = 0; i < subindex.size(); i++) {
				add(subindex.get(i));
		  }
	 }
	 /** Parsed data Constructor.
	  * @param raw A <strong>String</strong> containing a comma separated list of subcollection names.
	  * @param manager A reference to the <strong>SubcollectionManager</strong> via which we retrieve the required <strong>Subcollection</strong>s.
	  */
	 public DefaultSubIndex(String raw, SubcollectionManager manager) {
		  super(raw, manager);
	 }
	 /** Method to extract just the subindex information from this class.
	  * @return A <strong>SubIndex</strong> based on the information in this class.
	  */
	 public SubIndex getSubIndex() {
		  return new SubIndex(this);
	 }
	 /** Method to produce this class as a string much like you'd find in the collection configuration file.
	  * @return A <strong>String</string> with the default index entry.
	  */
	 public String toString() {
		  String text = "defaultsubcollection ";
		  for(int i = 0; i < size(); i++) {
				Object object = get(i);
				Subcollection sub = (Subcollection) get(i);
				text = text + sub.getName();
				if(i < size() - 1) {
					 text = text + ",";
				}
		  }
		  text = text + "\n";
		  return text;
	 }
}

